==> ejc-zypms-impl-3.0.0-20250815.130555-136-sources.jar: com/ejianc/business/sub/service/impl/SubFinishBpmServiceImpl.java <==
package com.ejianc.business.sub.service.impl;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.sub.bean.SubContractEntity;
import com.ejianc.business.sub.service.IContractService;
import com.ejianc.business.sub.service.ISubFinishService;
import com.ejianc.business.sub.vo.SubFinishVO;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;

/**
 * <p>
 * 分包零星用工表 审批流服务实现类
 * </p>
 *
 * @author zhangwx
 * @since 2020-06-05
 */
@Service("subFinish")
public class SubFinishBpmServiceImpl implements ICommonBusinessService {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private ISubFinishService finishService;

    @Autowired
    private IContractService contractService;

    @Autowired
    private IBillTypeApi billTypeApi;

    @Override
    public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        SubFinishVO finishEntity = finishService.queryDetail(billId);
        SubContractEntity contractEntity  = contractService.getById(finishEntity.getContractId());

        BigDecimal sumSettleTaxMny = contractEntity.getSumSettleTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumSettleTaxMny();
        BigDecimal sumSettleMny = contractEntity.getSumSettleMny() == null ? BigDecimal.ZERO : contractEntity.getSumSettleMny();
        BigDecimal settleTaxMny = finishEntity.getShouldPayTaxMny() == null ? BigDecimal.ZERO : finishEntity.getShouldPayTaxMny();
        BigDecimal settleMny = finishEntity.getShouldPayMny() == null ? BigDecimal.ZERO : finishEntity.getShouldPayMny();

        BigDecimal sumOddjobSettleTaxMny = contractEntity.getSumOddjobSettleTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumOddjobSettleTaxMny();
        BigDecimal sumOddjobSettleMny = contractEntity.getSumOddjobSettleMny() == null ? BigDecimal.ZERO : contractEntity.getSumOddjobSettleMny();
        BigDecimal jobTaxMny = finishEntity.getOddjobTaxMny() == null ? BigDecimal.ZERO : finishEntity.getOddjobTaxMny();
        BigDecimal jobMny = finishEntity.getOddjobMny() == null ? BigDecimal.ZERO : finishEntity.getOddjobMny();

        BigDecimal sumOtherTaxMny = contractEntity.getSumOtherTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumOtherTaxMny();
        BigDecimal sumOtherMny = contractEntity.getSumOtherMny() == null ? BigDecimal.ZERO : contractEntity.getSumOtherMny();
        BigDecimal otherTaxMny = finishEntity.getOtherTaxMny() == null ? BigDecimal.ZERO : finishEntity.getOtherTaxMny();
        BigDecimal otherMny = finishEntity.getOtherMny() == null ? BigDecimal.ZERO : finishEntity.getOtherMny();

        LambdaUpdateWrapper<SubContractEntity> updateWrapper = new LambdaUpdateWrapper<>();
//        updateWrapper.set(ContractEntity::getFinishFlag, Boolean.TRUE);
        updateWrapper.set(SubContractEntity::getSumSettleTaxMny, sumSettleTaxMny.add(settleTaxMny));
        updateWrapper.set(SubContractEntity::getSumSettleMny, sumSettleMny.add(settleMny));
        updateWrapper.set(SubContractEntity::getSumOddjobSettleTaxMny, sumOddjobSettleTaxMny.add(jobTaxMny));
        updateWrapper.set(SubContractEntity::getSumOddjobSettleMny, sumOddjobSettleMny.add(jobMny));
        updateWrapper.set(SubContractEntity::getSumOtherTaxMny, sumOtherTaxMny.add(otherTaxMny));
        updateWrapper.set(SubContractEntity::getSumOtherMny, sumOtherMny.add(otherMny));
        updateWrapper.eq(SubContractEntity::getId, finishEntity.getContractId());
        contractService.update(contractEntity, updateWrapper, false);

        return CommonResponse.success("审批回调合同成功！");
    }

    @Override
    public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state,String billTypeCode) {
        SubFinishVO finishEntity = finishService.queryDetail(billId);
        SubContractEntity contractEntity  = contractService.getById(finishEntity.getContractId());

        BigDecimal sumSettleTaxMny = contractEntity.getSumSettleTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumSettleTaxMny();
        BigDecimal sumSettleMny = contractEntity.getSumSettleMny() == null ? BigDecimal.ZERO : contractEntity.getSumSettleMny();
        BigDecimal settleTaxMny = finishEntity.getShouldPayTaxMny() == null ? BigDecimal.ZERO : finishEntity.getShouldPayTaxMny();
        BigDecimal settleMny = finishEntity.getShouldPayMny() == null ? BigDecimal.ZERO : finishEntity.getShouldPayMny();

        BigDecimal sumOddjobSettleTaxMny = contractEntity.getSumOddjobSettleTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumOddjobSettleTaxMny();
        BigDecimal sumOddjobSettleMny = contractEntity.getSumOddjobSettleMny() == null ? BigDecimal.ZERO : contractEntity.getSumOddjobSettleMny();
        BigDecimal jobTaxMny = finishEntity.getOddjobTaxMny() == null ? BigDecimal.ZERO : finishEntity.getOddjobTaxMny();
        BigDecimal jobMny = finishEntity.getOddjobMny() == null ? BigDecimal.ZERO : finishEntity.getOddjobMny();

        BigDecimal sumOtherTaxMny = contractEntity.getSumOtherTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumOtherTaxMny();
        BigDecimal sumOtherMny = contractEntity.getSumOtherMny() == null ? BigDecimal.ZERO : contractEntity.getSumOtherMny();
        BigDecimal otherTaxMny = finishEntity.getOtherTaxMny() == null ? BigDecimal.ZERO : finishEntity.getOtherTaxMny();
        BigDecimal otherMny = finishEntity.getOtherMny() == null ? BigDecimal.ZERO : finishEntity.getOtherMny();

        LambdaUpdateWrapper<SubContractEntity> updateWrapper = new LambdaUpdateWrapper<>();
//        updateWrapper.set(ContractEntity::getFinishFlag, Boolean.FALSE);
        updateWrapper.set(SubContractEntity::getSumSettleTaxMny, sumSettleTaxMny.subtract(settleTaxMny));
        updateWrapper.set(SubContractEntity::getSumSettleMny, sumSettleMny.subtract(settleMny));
        updateWrapper.set(SubContractEntity::getSumOddjobSettleTaxMny, sumOddjobSettleTaxMny.subtract(jobTaxMny));
        updateWrapper.set(SubContractEntity::getSumOddjobSettleMny, sumOddjobSettleMny.subtract(jobMny));
        updateWrapper.set(SubContractEntity::getSumOtherTaxMny, sumOtherTaxMny.subtract(otherTaxMny));
        updateWrapper.set(SubContractEntity::getSumOtherMny, sumOtherMny.subtract(otherMny));
        updateWrapper.eq(SubContractEntity::getId, finishEntity.getContractId());
        contractService.update(contractEntity, updateWrapper, false);

        return CommonResponse.success("审批回调合同成功！");
    }

    @Override
    public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state,String billTypeCode) {
        //TO DO 结算单是否被其他引用
        CommonResponse<String>  res = billTypeApi.checkQuote(billTypeCode,billId);
        logger.info("平台返回查询被引用情况"+res.isSuccess()+"----"+res.getMsg());
        if(res.isSuccess()) {//单据未被下游单据引用
            return CommonResponse.success();
        }else{
            return CommonResponse.error(res.getMsg());
        }
    }

}

==> ejc-zypms-impl-3.0.0-20251120.110454-157-sources.jar: com/ejianc/business/sub/service/impl/SubFinishBpmServiceImpl.java <==
package com.ejianc.business.sub.service.impl;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.sub.bean.SubContractEntity;
import com.ejianc.business.sub.service.IContractService;
import com.ejianc.business.sub.service.ISubFinishService;
import com.ejianc.business.sub.vo.SubFinishVO;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;

/**
 * <p>
 * 分包零星用工表 审批流服务实现类
 * </p>
 *
 * @author zhangwx
 * @since 2020-06-05
 */
@Service("subFinish")
public class SubFinishBpmServiceImpl implements ICommonBusinessService {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private ISubFinishService finishService;

    @Autowired
    private IContractService contractService;

    @Autowired
    private IBillTypeApi billTypeApi;

    @Override
    public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        SubFinishVO finishEntity = finishService.queryDetail(billId);
        SubContractEntity contractEntity  = contractService.getById(finishEntity.getContractId());

        BigDecimal sumSettleTaxMny = contractEntity.getSumSettleTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumSettleTaxMny();
        BigDecimal sumSettleMny = contractEntity.getSumSettleMny() == null ? BigDecimal.ZERO : contractEntity.getSumSettleMny();
        BigDecimal settleTaxMny = finishEntity.getShouldPayTaxMny() == null ? BigDecimal.ZERO : finishEntity.getShouldPayTaxMny();
        BigDecimal settleMny = finishEntity.getShouldPayMny() == null ? BigDecimal.ZERO : finishEntity.getShouldPayMny();

        BigDecimal sumOddjobSettleTaxMny = contractEntity.getSumOddjobSettleTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumOddjobSettleTaxMny();
        BigDecimal sumOddjobSettleMny = contractEntity.getSumOddjobSettleMny() == null ? BigDecimal.ZERO : contractEntity.getSumOddjobSettleMny();
        BigDecimal jobTaxMny = finishEntity.getOddjobTaxMny() == null ? BigDecimal.ZERO : finishEntity.getOddjobTaxMny();
        BigDecimal jobMny = finishEntity.getOddjobMny() == null ? BigDecimal.ZERO : finishEntity.getOddjobMny();

        BigDecimal sumOtherTaxMny = contractEntity.getSumOtherTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumOtherTaxMny();
        BigDecimal sumOtherMny = contractEntity.getSumOtherMny() == null ? BigDecimal.ZERO : contractEntity.getSumOtherMny();
        BigDecimal otherTaxMny = finishEntity.getOtherTaxMny() == null ? BigDecimal.ZERO : finishEntity.getOtherTaxMny();
        BigDecimal otherMny = finishEntity.getOtherMny() == null ? BigDecimal.ZERO : finishEntity.getOtherMny();

        LambdaUpdateWrapper<SubContractEntity> updateWrapper = new LambdaUpdateWrapper<>();
//        updateWrapper.set(ContractEntity::getFinishFlag, Boolean.TRUE);
        updateWrapper.set(SubContractEntity::getSumSettleTaxMny, sumSettleTaxMny.add(settleTaxMny));
        updateWrapper.set(SubContractEntity::getSumSettleMny, sumSettleMny.add(settleMny));
        updateWrapper.set(SubContractEntity::getSumOddjobSettleTaxMny, sumOddjobSettleTaxMny.add(jobTaxMny));
        updateWrapper.set(SubContractEntity::getSumOddjobSettleMny, sumOddjobSettleMny.add(jobMny));
        updateWrapper.set(SubContractEntity::getSumOtherTaxMny, sumOtherTaxMny.add(otherTaxMny));
        updateWrapper.set(SubContractEntity::getSumOtherMny, sumOtherMny.add(otherMny));
        updateWrapper.eq(SubContractEntity::getId, finishEntity.getContractId());
        contractService.update(updateWrapper);

        return CommonResponse.success("审批回调合同成功！");
    }

    @Override
    public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state,String billTypeCode) {
        SubFinishVO finishEntity = finishService.queryDetail(billId);
        SubContractEntity contractEntity  = contractService.getById(finishEntity.getContractId());

        BigDecimal sumSettleTaxMny = contractEntity.getSumSettleTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumSettleTaxMny();
        BigDecimal sumSettleMny = contractEntity.getSumSettleMny() == null ? BigDecimal.ZERO : contractEntity.getSumSettleMny();
        BigDecimal settleTaxMny = finishEntity.getShouldPayTaxMny() == null ? BigDecimal.ZERO : finishEntity.getShouldPayTaxMny();
        BigDecimal settleMny = finishEntity.getShouldPayMny() == null ? BigDecimal.ZERO : finishEntity.getShouldPayMny();

        BigDecimal sumOddjobSettleTaxMny = contractEntity.getSumOddjobSettleTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumOddjobSettleTaxMny();
        BigDecimal sumOddjobSettleMny = contractEntity.getSumOddjobSettleMny() == null ? BigDecimal.ZERO : contractEntity.getSumOddjobSettleMny();
        BigDecimal jobTaxMny = finishEntity.getOddjobTaxMny() == null ? BigDecimal.ZERO : finishEntity.getOddjobTaxMny();
        BigDecimal jobMny = finishEntity.getOddjobMny() == null ? BigDecimal.ZERO : finishEntity.getOddjobMny();

        BigDecimal sumOtherTaxMny = contractEntity.getSumOtherTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumOtherTaxMny();
        BigDecimal sumOtherMny = contractEntity.getSumOtherMny() == null ? BigDecimal.ZERO : contractEntity.getSumOtherMny();
        BigDecimal otherTaxMny = finishEntity.getOtherTaxMny() == null ? BigDecimal.ZERO : finishEntity.getOtherTaxMny();
        BigDecimal otherMny = finishEntity.getOtherMny() == null ? BigDecimal.ZERO : finishEntity.getOtherMny();

        LambdaUpdateWrapper<SubContractEntity> updateWrapper = new LambdaUpdateWrapper<>();
//        updateWrapper.set(ContractEntity::getFinishFlag, Boolean.FALSE);
        updateWrapper.set(SubContractEntity::getSumSettleTaxMny, sumSettleTaxMny.subtract(settleTaxMny));
        updateWrapper.set(SubContractEntity::getSumSettleMny, sumSettleMny.subtract(settleMny));
        updateWrapper.set(SubContractEntity::getSumOddjobSettleTaxMny, sumOddjobSettleTaxMny.subtract(jobTaxMny));
        updateWrapper.set(SubContractEntity::getSumOddjobSettleMny, sumOddjobSettleMny.subtract(jobMny));
        updateWrapper.set(SubContractEntity::getSumOtherTaxMny, sumOtherTaxMny.subtract(otherTaxMny));
        updateWrapper.set(SubContractEntity::getSumOtherMny, sumOtherMny.subtract(otherMny));
        updateWrapper.eq(SubContractEntity::getId, finishEntity.getContractId());
        contractService.update(updateWrapper);

        return CommonResponse.success("审批回调合同成功！");
    }

    @Override
    public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state,String billTypeCode) {
        //TO DO 结算单是否被其他引用
        CommonResponse<String>  res = billTypeApi.checkQuote(billTypeCode,billId);
        logger.info("平台返回查询被引用情况"+res.isSuccess()+"----"+res.getMsg());
        if(res.isSuccess()) {//单据未被下游单据引用
            return CommonResponse.success();
        }else{
            return CommonResponse.error(res.getMsg());
        }
    }

}
